#include "display-lib.h"
#include "LCD.h"
#include "SPI.h"
#include "UART.h"

volatile uint8_t lcd_current_page = 0;
volatile uint8_t lcd_current_column = 0;

void lcd_data(uint8_t data) {
    WDB(data);  
    lcd_inc_column(1);
}

/******************************************************************************
 * Writes one command byte
 * cmd           - the command byte
 */
void lcd_command(uint8_t cmd) {
	CD = OFF;
    SPIsend(cmd, LCD);
    
}

/******************************************************************************
 * Changes the internal cursor by s pages
 * s             - number of pages to move
 */
uint8_t lcd_inc_page(uint8_t s) {
    uint8_t p = lcd_current_page;
    p += s;
    p %= LCD_RAM_PAGES; //all lcd have lcd_ram_pages which is power of two
    lcd_current_page = p;
    return p;
}

/******************************************************************************
 * Changes the internal cursor by s columns, including wrapping (if selected)
 * s             - number of columns to move
 */
uint8_t lcd_inc_column(uint8_t s) {
    uint8_t c = lcd_current_column;
    

    
        
    c += s;
#if LCD_WRAP_AROUND == 1
    while (c >= LCD_WIDTH) {
        if (s > 0) lcd_inc_page(1);
        else lcd_inc_page(-1);
        if (s > 0) c -= LCD_WIDTH;
        else c += LCD_WIDTH;
    }
#endif
    lcd_current_column = c;
//    UART_Send_String("\n return c: ");
//    UART_Send(0x0A); // '\n'
//    UART_Send(c);
//    UART_Send(0x0A); // '\n'
//
    return c;
}

/******************************************************************************
 * Moves the cursor to the given position
 * pages         - page to move to
 * columns       - column to move to
 */
void lcd_moveto_xy(uint8_t page, uint8_t column) {
	
//	UART_Send_String("lcd_moveto_xy: page: "); 
//	UART_Send(page);UART_Send('\n');
//	UART_Send_String("lcd_moveto_xy: column: "); 
//	UART_Send(column);UART_Send('\n');
		
    LCD_GOTO_ADDRESS(page, column);
    lcd_current_column = column;
    lcd_current_page = page;
}

/******************************************************************************
 * Moves the cursor relative to the current position
 * pages         - number of pages to move
 * columns       - number of columns to move
 */
void lcd_move_xy(int8_t pages, int16_t columns) {
//	UART_Send_String("\n lcd_move_xy: ");
//    UART_Send(0x0A); // '\n'
//    UART_Send(columns);
//    UART_Send(0x0A); // '\n'
    lcd_moveto_xy(lcd_inc_page(pages), lcd_inc_column(columns));
}

/******************************************************************************
 * This function clears an area of the screen
 * pages         - height of area in pages
 * columns       - width of area in pixels
 * style         - Bit2: sets inverse mode
 * Cursor is moved to start of area after clear
 */
void lcd_clear_area(uint8_t pages, uint8_t columns, uint8_t style) {
    uint8_t i, j, max;
    uint8_t inv = (style & INVERT_BIT) ? 0xFF : 0;

    if (pages > (max = LCD_RAM_PAGES - lcd_get_position_page()))
        pages = max;
    if (columns > (max = LCD_WIDTH - lcd_get_position_column()))
        columns = max;

    for (j = 0; j < pages; j++) {
        for (i = 0; i < columns; i++) {
            lcd_data(inv);
        }
        lcd_move_xy((lcd_get_position_column() ? 1 : 0), -columns);
    }
    lcd_move_xy(-pages, 0);
}



