#ifndef _DISPLAY_LIB_H
#define _DISPLAY_LIB_H

#include "Main.h"

#define DISPLAY_TYPE 102

#if DISPLAY_TYPE == 102
  #define LCD_WIDTH          102 //width of the LCD
  #define LCD_HEIGHT         64  //height of the LCD
  #define LCD_RAM_PAGES      8   //size of LCD RAM
  #define LCD_PIXEL_PER_BYTE 8   //using single pixels
  #define LCD_PAGE_ADDRESS      0xB0  //3: Page address set (lower 4 bits select one of the pages)
  #define LCD_COL_ADDRESS       0x10  //4: column address 
#endif


extern volatile uint8_t lcd_current_page;
extern volatile uint8_t lcd_current_column;


//write data word or command to the LCD
void lcd_data     (uint8_t data);
void lcd_command  (uint8_t cmd);

static inline uint8_t lcd_get_position_page(void)   {return lcd_current_page;}
static inline uint8_t lcd_get_position_column(void) {return lcd_current_column;}

uint8_t lcd_inc_page(uint8_t s);
uint8_t lcd_inc_column(uint8_t s);

#define LCD_GOTO_ADDRESS(page,col)    lcd_command(LCD_PAGE_ADDRESS | ((page) & 0x0F)); \
                                        lcd_command(LCD_COL_ADDRESS | (((col)>>4) & 0x0F)); \
                                        lcd_command(((col) & 0x0F))

void lcd_moveto_xy(uint8_t page, uint8_t column);
void lcd_move_xy(int8_t pages, int16_t columns);
void lcd_clear_area(uint8_t pages, uint8_t columns, uint8_t style);



//Bit positions for style settings
#define NORMAL      0
#define INVERT      4
#define INVERT_BIT  4

#endif